==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/InstytucjaWplataPozycjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class InstytucjaWplataPozycjaKey extends GenericDPSObject {
    /**
     * INSTYTUCJA_WPLATA_POZYCJA.INSTYTUCJA_WPLATA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long instytucjaWplataId;

    /**
     * INSTYTUCJA_WPLATA_POZYCJA.WPLATA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long wplataId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INSTYTUCJA_WPLATA_POZYCJA.INSTYTUCJA_WPLATA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInstytucjaWplataId() {
        return instytucjaWplataId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:43
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * INSTYTUCJA_WPLATA_POZYCJA.INSTYTUCJA_WPLATA_ID
     *
     * @param instytucjaWplataId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInstytucjaWplataId(Long instytucjaWplataId) {
        this.instytucjaWplataId = instytucjaWplataId;
    }

    /**
     * @return INSTYTUCJA_WPLATA_POZYCJA.WPLATA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getWplataId() {
        return wplataId;
    }

    /**
     * INSTYTUCJA_WPLATA_POZYCJA.WPLATA_ID
     *
     * @param wplataId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWplataId(Long wplataId) {
        this.wplataId = wplataId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InstytucjaWplataPozycjaKey other = (InstytucjaWplataPozycjaKey) that;
        return (this.getInstytucjaWplataId() == null ? other.getInstytucjaWplataId() == null : this.getInstytucjaWplataId().equals(other.getInstytucjaWplataId()))
            && (this.getWplataId() == null ? other.getWplataId() == null : this.getWplataId().equals(other.getWplataId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getInstytucjaWplataId() == null) ? 0 : getInstytucjaWplataId().hashCode());
        result = prime * result + ((getWplataId() == null) ? 0 : getWplataId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", instytucjaWplataId=").append(instytucjaWplataId);
        sb.append(", wplataId=").append(wplataId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/InstytucjaWplataPozycjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class InstytucjaWplataPozycjaKey extends GenericDPSObject {
    /**
     * INSTYTUCJA_WPLATA_POZYCJA.INSTYTUCJA_WPLATA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long instytucjaWplataId;

    /**
     * INSTYTUCJA_WPLATA_POZYCJA.WPLATA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long wplataId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INSTYTUCJA_WPLATA_POZYCJA.INSTYTUCJA_WPLATA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInstytucjaWplataId() {
        return instytucjaWplataId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:48
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * INSTYTUCJA_WPLATA_POZYCJA.INSTYTUCJA_WPLATA_ID
     *
     * @param instytucjaWplataId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInstytucjaWplataId(Long instytucjaWplataId) {
        this.instytucjaWplataId = instytucjaWplataId;
    }

    /**
     * @return INSTYTUCJA_WPLATA_POZYCJA.WPLATA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getWplataId() {
        return wplataId;
    }

    /**
     * INSTYTUCJA_WPLATA_POZYCJA.WPLATA_ID
     *
     * @param wplataId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWplataId(Long wplataId) {
        this.wplataId = wplataId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InstytucjaWplataPozycjaKey other = (InstytucjaWplataPozycjaKey) that;
        return (this.getInstytucjaWplataId() == null ? other.getInstytucjaWplataId() == null : this.getInstytucjaWplataId().equals(other.getInstytucjaWplataId()))
            && (this.getWplataId() == null ? other.getWplataId() == null : this.getWplataId().equals(other.getWplataId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getInstytucjaWplataId() == null) ? 0 : getInstytucjaWplataId().hashCode());
        result = prime * result + ((getWplataId() == null) ? 0 : getWplataId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", instytucjaWplataId=").append(instytucjaWplataId);
        sb.append(", wplataId=").append(wplataId);
        sb.append("]");
        return sb.toString();
    }
}
